@@ -600,19 +600,19 @@ EOT
                         }
                     }
 
-                    $io->write('');
-                    $io->write('<info>Direct dependencies required in composer.json:</>');
+                    $io->writeError('');
+                    $io->writeError('<info>Direct dependencies required in composer.json:</>');
                     if (\count($directDeps) > 0) {
                         $this->printPackages($io, $directDeps, $indent, $versionFits, $latestFits, $descriptionFits, $width, $versionLength, $nameLength, $latestLength);
                     } else {
-                        $io->write('Everything up to date');
+                        $io->writeError('Everything up to date');
                     }
-                    $io->write('');
-                    $io->write('<info>Transitive dependencies not required in composer.json:</>');
+                    $io->writeError('');
+                    $io->writeError('<info>Transitive dependencies not required in composer.json:</>');
                     if (\count($transitiveDeps) > 0) {
                         $this->printPackages($io, $transitiveDeps, $indent, $versionFits, $latestFits, $descriptionFits, $width, $versionLength, $nameLength, $latestLength);
                     } else {
-                        $io->write('Everything up to date');
+                        $io->writeError('Everything up to date');
                     }
                 } else {
                     $this->printPackages($io, $packages, $indent, $versionFits, $latestFits, $descriptionFits, $width, $versionLength, $nameLength, $latestLength);
@@ -677,7 +677,12 @@ EOT
      */
     protected function getRootRequires(): array
     {
-        $rootPackage = $this->requireComposer()->getPackage();
+        $composer = $this->tryComposer();
+        if ($composer === null) {
+            return [];
+        }
+
+        $rootPackage = $composer->getPackage();
 
         return array_map(
             'strtolower',
@@ -1356,8 +1361,8 @@ EOT
         }
 
         if ($targetVersion === null) {
-            if ($majorOnly && Preg::isMatch('{^(\d+)\.}', $package->getVersion(), $match)) {
-                $targetVersion = '>='.($match[1] + 1).',<9999999-dev';
+            if ($majorOnly && Preg::isMatch('{^(?P<zero_major>(?:0\.)+)?(?P<first_meaningful>\d+)\.}', $package->getVersion(), $match)) {
+                $targetVersion = '>='.$match['zero_major'].($match['first_meaningful'] + 1).',<9999999-dev';
             }
 
             if ($minorOnly) {
