@@ -21,13 +21,13 @@ use Composer\Pcre\Preg;
 use Composer\Plugin\CommandEvent;
 use Composer\Plugin\PluginEvents;
 use Composer\Package\Version\VersionParser;
+use Composer\Semver\Intervals;
 use Composer\Util\HttpDownloader;
-use Composer\Semver\Constraint\MultiConstraint;
-use Composer\Package\Link;
+use Composer\Advisory\Auditor;
 use Symfony\Component\Console\Helper\Table;
 use Symfony\Component\Console\Input\InputInterface;
-use Symfony\Component\Console\Input\InputOption;
-use Symfony\Component\Console\Input\InputArgument;
+use Composer\Console\Input\InputOption;
+use Composer\Console\Input\InputArgument;
 use Symfony\Component\Console\Output\OutputInterface;
 use Symfony\Component\Console\Question\Question;
 
@@ -37,6 +37,8 @@ use Symfony\Component\Console\Question\Question;
  */
 class UpdateCommand extends BaseCommand
 {
+    use CompletionTrait;
+
     /**
      * @return void
      */
@@ -44,19 +46,21 @@ class UpdateCommand extends BaseCommand
     {
         $this
             ->setName('update')
-            ->setAliases(array('u', 'upgrade'))
-            ->setDescription('Updates your dependencies to the latest version according to composer.json, and updates the composer.lock file.')
-            ->setDefinition(array(
-                new InputArgument('packages', InputArgument::IS_ARRAY | InputArgument::OPTIONAL, 'Packages that should be updated, if not provided all packages are.'),
+            ->setAliases(['u', 'upgrade'])
+            ->setDescription('Updates your dependencies to the latest version according to composer.json, and updates the composer.lock file')
+            ->setDefinition([
+                new InputArgument('packages', InputArgument::IS_ARRAY | InputArgument::OPTIONAL, 'Packages that should be updated, if not provided all packages are.', null, $this->suggestInstalledPackage(false)),
                 new InputOption('with', null, InputOption::VALUE_IS_ARRAY | InputOption::VALUE_REQUIRED, 'Temporary version constraint to add, e.g. foo/bar:1.0.0 or foo/bar=1.0.0'),
                 new InputOption('prefer-source', null, InputOption::VALUE_NONE, 'Forces installation from package sources when possible, including VCS information.'),
                 new InputOption('prefer-dist', null, InputOption::VALUE_NONE, 'Forces installation from package dist (default behavior).'),
-                new InputOption('prefer-install', null, InputOption::VALUE_REQUIRED, 'Forces installation from package dist|source|auto (auto chooses source for dev versions, dist for the rest).'),
+                new InputOption('prefer-install', null, InputOption::VALUE_REQUIRED, 'Forces installation from package dist|source|auto (auto chooses source for dev versions, dist for the rest).', null, $this->suggestPreferInstall()),
                 new InputOption('dry-run', null, InputOption::VALUE_NONE, 'Outputs the operations but will not execute anything (implicitly enables --verbose).'),
                 new InputOption('dev', null, InputOption::VALUE_NONE, 'DEPRECATED: Enables installation of require-dev packages (enabled by default, only present for BC).'),
                 new InputOption('no-dev', null, InputOption::VALUE_NONE, 'Disables installation of require-dev packages.'),
                 new InputOption('lock', null, InputOption::VALUE_NONE, 'Overwrites the lock file hash to suppress warning about the lock file being out of date without updating package versions. Package metadata like mirrors and URLs are updated if they changed.'),
                 new InputOption('no-install', null, InputOption::VALUE_NONE, 'Skip the install step after updating the composer.lock file.'),
+                new InputOption('no-audit', null, InputOption::VALUE_NONE, 'Skip the audit step after updating the composer.lock file (can also be set via the COMPOSER_NO_AUDIT=1 env var).'),
+                new InputOption('audit-format', null, InputOption::VALUE_REQUIRED, 'Audit output format. Must be "table", "plain", "json", or "summary".', Auditor::FORMAT_SUMMARY, Auditor::FORMATS),
                 new InputOption('no-autoloader', null, InputOption::VALUE_NONE, 'Skips autoloader generation'),
                 new InputOption('no-suggest', null, InputOption::VALUE_NONE, 'DEPRECATED: This flag does not exist anymore.'),
                 new InputOption('no-progress', null, InputOption::VALUE_NONE, 'Do not output download progress.'),
@@ -69,11 +73,11 @@ class UpdateCommand extends BaseCommand
                 new InputOption('apcu-autoloader-prefix', null, InputOption::VALUE_REQUIRED, 'Use a custom prefix for the APCu autoloader cache. Implicitly enables --apcu-autoloader'),
                 new InputOption('ignore-platform-req', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY, 'Ignore a specific platform requirement (php & ext- packages).'),
                 new InputOption('ignore-platform-reqs', null, InputOption::VALUE_NONE, 'Ignore all platform requirements (php & ext- packages).'),
-                new InputOption('prefer-stable', null, InputOption::VALUE_NONE, 'Prefer stable versions of dependencies.'),
-                new InputOption('prefer-lowest', null, InputOption::VALUE_NONE, 'Prefer lowest versions of dependencies.'),
+                new InputOption('prefer-stable', null, InputOption::VALUE_NONE, 'Prefer stable versions of dependencies (can also be set via the COMPOSER_PREFER_STABLE=1 env var).'),
+                new InputOption('prefer-lowest', null, InputOption::VALUE_NONE, 'Prefer lowest versions of dependencies (can also be set via the COMPOSER_PREFER_LOWEST=1 env var).'),
                 new InputOption('interactive', 'i', InputOption::VALUE_NONE, 'Interactive interface with autocompletion to select the packages to update.'),
                 new InputOption('root-reqs', null, InputOption::VALUE_NONE, 'Restricts the update to your first degree dependencies.'),
-            ))
+            ])
             ->setHelp(
                 <<<EOT
 The <info>update</info> command reads the composer.json file from the
@@ -129,7 +133,7 @@ EOT
 
         // extract --with shorthands from the allowlist
         if (count($packages) > 0) {
-            $allowlistPackagesWithRequirements = array_filter($packages, function ($pkg): bool {
+            $allowlistPackagesWithRequirements = array_filter($packages, static function ($pkg): bool {
                 return Preg::isMatch('{\S+[ =:]\S+}', $pkg);
             });
             foreach ($this->formatRequirements($allowlistPackagesWithRequirements) as $package => $constraint) {
@@ -145,30 +149,29 @@ EOT
         }
 
         $rootPackage = $composer->getPackage();
-        $rootRequires = $rootPackage->getRequires();
-        $rootDevRequires = $rootPackage->getDevRequires();
-        foreach ($reqs as $package => $constraint) {
-            if (isset($rootRequires[$package])) {
-                $rootRequires[$package] = $this->appendConstraintToLink($rootRequires[$package], $constraint);
-            } elseif (isset($rootDevRequires[$package])) {
-                $rootDevRequires[$package] = $this->appendConstraintToLink($rootDevRequires[$package], $constraint);
-            } else {
-                throw new \UnexpectedValueException('Only root package requirements can receive temporary constraints and '.$package.' is not one');
-            }
-        }
-        $rootPackage->setRequires($rootRequires);
-        $rootPackage->setDevRequires($rootDevRequires);
         $rootPackage->setReferences(RootPackageLoader::extractReferences($reqs, $rootPackage->getReferences()));
         $rootPackage->setStabilityFlags(RootPackageLoader::extractStabilityFlags($reqs, $rootPackage->getMinimumStability(), $rootPackage->getStabilityFlags()));
 
+        $parser = new VersionParser;
+        $temporaryConstraints = [];
+        $rootRequirements = array_merge($rootPackage->getRequires(), $rootPackage->getDevRequires());
+        foreach ($reqs as $package => $constraint) {
+            $package = strtolower($package);
+            $parsedConstraint = $parser->parseConstraints($constraint);
+            $temporaryConstraints[$package] = $parsedConstraint;
+            if (isset($rootRequirements[$package]) && !Intervals::haveIntersections($parsedConstraint, $rootRequirements[$package]->getConstraint())) {
+                throw new \InvalidArgumentException('The temporary constraint "'.$constraint.'" for "'.$package.'" must be a subset of the constraint in your composer.json ('.$rootRequirements[$package]->getPrettyConstraint().')');
+            }
+        }
+
         if ($input->getOption('interactive')) {
             $packages = $this->getPackagesInteractively($io, $input, $output, $composer, $packages);
         }
 
         if ($input->getOption('root-reqs')) {
-            $requires = array_keys($rootRequires);
+            $requires = array_keys($rootPackage->getRequires());
             if (!$input->getOption('no-dev')) {
-                $requires = array_merge($requires, array_keys($rootDevRequires));
+                $requires = array_merge($requires, array_keys($rootPackage->getDevRequires()));
             }
 
             if (!empty($packages)) {
@@ -180,10 +183,10 @@ EOT
 
         // the arguments lock/nothing/mirrors are not package names but trigger a mirror update instead
         // they are further mutually exclusive with listing actual package names
-        $filteredPackages = array_filter($packages, function ($package): bool {
-            return !in_array($package, array('lock', 'nothing', 'mirrors'), true);
+        $filteredPackages = array_filter($packages, static function ($package): bool {
+            return !in_array($package, ['lock', 'nothing', 'mirrors'], true);
         });
-        $updateMirrors = $input->getOption('lock') || count($filteredPackages) != count($packages);
+        $updateMirrors = $input->getOption('lock') || count($filteredPackages) !== count($packages);
         $packages = $filteredPackages;
 
         if ($updateMirrors && !empty($packages)) {
@@ -200,7 +203,7 @@ EOT
         $install = Installer::create($io, $composer);
 
         $config = $composer->getConfig();
-        list($preferSource, $preferDist) = $this->getPreferredInstallOptions($config, $input);
+        [$preferSource, $preferDist] = $this->getPreferredInstallOptions($config, $input);
 
         $optimize = $input->getOption('optimize-autoloader') || $config->get('optimize-autoloader');
         $authoritative = $input->getOption('classmap-authoritative') || $config->get('classmap-authoritative');
@@ -232,6 +235,9 @@ EOT
             ->setPlatformRequirementFilter($this->getPlatformRequirementFilter($input))
             ->setPreferStable($input->getOption('prefer-stable'))
             ->setPreferLowest($input->getOption('prefer-lowest'))
+            ->setTemporaryConstraints($temporaryConstraints)
+            ->setAudit(!$input->getOption('no-audit'))
+            ->setAuditFormat($this->getAuditFormat($input))
         ;
 
         if ($input->getOption('no-plugins')) {
@@ -255,7 +261,7 @@ EOT
             $composer->getPackage()->getRequires(),
             $composer->getPackage()->getDevRequires()
         );
-        $autocompleterValues = array();
+        $autocompleterValues = [];
         foreach ($requires as $require) {
             $target = $require->getTarget();
             $autocompleterValues[strtolower($target)] = $target;
@@ -292,9 +298,9 @@ EOT
         }
 
         $table = new Table($output);
-        $table->setHeaders(array('Selected packages'));
+        $table->setHeaders(['Selected packages']);
         foreach ($packages as $package) {
-            $table->addRow(array($package));
+            $table->addRow([$package]);
         }
         $table->render();
 
@@ -307,25 +313,4 @@ EOT
 
         throw new \RuntimeException('Installation aborted.');
     }
-
-    /**
-     * @param string $constraint
-     * @return Link
-     */
-    private function appendConstraintToLink(Link $link, string $constraint): Link
-    {
-        $parser = new VersionParser;
-        $oldPrettyString = $link->getConstraint()->getPrettyString();
-        $newConstraint = MultiConstraint::create(array($link->getConstraint(), $parser->parseConstraints($constraint)));
-        $newConstraint->setPrettyString($oldPrettyString.', '.$constraint);
-
-        return new Link(
-            $link->getSource(),
-            $link->getTarget(),
-            $newConstraint,
-            /** @phpstan-ignore-next-line */
-            $link->getDescription(),
-            $link->getPrettyConstraint() . ', ' . $constraint
-        );
-    }
 }
