@@ -23,7 +23,7 @@ use Symfony\Component\Console\Formatter\OutputFormatterStyle;
 class HtmlOutputFormatter extends OutputFormatter
 {
     /** @var array<int, string> */
-    private static $availableForegroundColors = array(
+    private static $availableForegroundColors = [
         30 => 'black',
         31 => 'red',
         32 => 'green',
@@ -32,9 +32,9 @@ class HtmlOutputFormatter extends OutputFormatter
         35 => 'magenta',
         36 => 'cyan',
         37 => 'white',
-    );
+    ];
     /** @var array<int, string> */
-    private static $availableBackgroundColors = array(
+    private static $availableBackgroundColors = [
         40 => 'black',
         41 => 'red',
         42 => 'green',
@@ -43,20 +43,20 @@ class HtmlOutputFormatter extends OutputFormatter
         45 => 'magenta',
         46 => 'cyan',
         47 => 'white',
-    );
+    ];
     /** @var array<int, string> */
-    private static $availableOptions = array(
+    private static $availableOptions = [
         1 => 'bold',
         4 => 'underscore',
         //5 => 'blink',
         //7 => 'reverse',
         //8 => 'conceal'
-    );
+    ];
 
     /**
      * @param array<string, OutputFormatterStyle> $styles Array of "name => FormatterStyle" instances
      */
-    public function __construct(array $styles = array())
+    public function __construct(array $styles = [])
     {
         parent::__construct(true, $styles);
     }
