@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -21,45 +21,44 @@ use Composer\Repository\RepositorySet;
 class RuleSet implements \IteratorAggregate, \Countable
 {
     // highest priority => lowest number
-    const TYPE_PACKAGE = 0;
-    const TYPE_REQUEST = 1;
-    const TYPE_LEARNED = 4;
+    public const TYPE_PACKAGE = 0;
+    public const TYPE_REQUEST = 1;
+    public const TYPE_LEARNED = 4;
 
     /**
      * READ-ONLY: Lookup table for rule id to rule object
      *
      * @var array<int, Rule>
      */
-    public $ruleById = array();
+    public $ruleById = [];
 
     /** @var array<0|1|4, string> */
-    protected static $types = array(
+    protected static $types = [
         self::TYPE_PACKAGE => 'PACKAGE',
         self::TYPE_REQUEST => 'REQUEST',
         self::TYPE_LEARNED => 'LEARNED',
-    );
+    ];
 
     /** @var array<self::TYPE_*, Rule[]> */
     protected $rules;
 
-    /** @var int */
+    /** @var 0|positive-int */
     protected $nextRuleId = 0;
 
     /** @var array<int|string, Rule|Rule[]> */
-    protected $rulesByHash = array();
+    protected $rulesByHash = [];
 
     public function __construct()
     {
         foreach ($this->getTypes() as $type) {
-            $this->rules[$type] = array();
+            $this->rules[$type] = [];
         }
     }
 
     /**
      * @param self::TYPE_* $type
-     * @return void
      */
-    public function add(Rule $rule, $type)
+    public function add(Rule $rule, $type): void
     {
         if (!isset(self::$types[$type])) {
             throw new \OutOfBoundsException('Unknown rule type: ' . $type);
@@ -84,7 +83,7 @@ class RuleSet implements \IteratorAggregate, \Countable
         }
 
         if (!isset($this->rules[$type])) {
-            $this->rules[$type] = array();
+            $this->rules[$type] = [];
         }
 
         $this->rules[$type][] = $rule;
@@ -99,57 +98,44 @@ class RuleSet implements \IteratorAggregate, \Countable
             $this->rulesByHash[$hash][] = $rule;
         } else {
             $originalRule = $this->rulesByHash[$hash];
-            $this->rulesByHash[$hash] = array($originalRule, $rule);
+            $this->rulesByHash[$hash] = [$originalRule, $rule];
         }
     }
 
-    /**
-     * @return int
-     */
-    #[\ReturnTypeWillChange]
-    public function count()
+    public function count(): int
     {
         return $this->nextRuleId;
     }
 
-    /**
-     * @param int $id
-     * @return Rule
-     */
-    public function ruleById($id)
+    public function ruleById(int $id): Rule
     {
         return $this->ruleById[$id];
     }
 
     /** @return array<self::TYPE_*, Rule[]> */
-    public function getRules()
+    public function getRules(): array
     {
         return $this->rules;
     }
 
-    /**
-     * @return RuleSetIterator
-     */
-    #[\ReturnTypeWillChange]
-    public function getIterator()
+    public function getIterator(): RuleSetIterator
     {
         return new RuleSetIterator($this->getRules());
     }
 
     /**
      * @param  self::TYPE_*|array<self::TYPE_*> $types
-     * @return RuleSetIterator
      */
-    public function getIteratorFor($types)
+    public function getIteratorFor($types): RuleSetIterator
     {
         if (!\is_array($types)) {
-            $types = array($types);
+            $types = [$types];
         }
 
         $allRules = $this->getRules();
 
         /** @var array<self::TYPE_*, Rule[]> $rules */
-        $rules = array();
+        $rules = [];
 
         foreach ($types as $type) {
             $rules[$type] = $allRules[$type];
@@ -160,12 +146,11 @@ class RuleSet implements \IteratorAggregate, \Countable
 
     /**
      * @param array<self::TYPE_*>|self::TYPE_* $types
-     * @return RuleSetIterator
      */
-    public function getIteratorWithout($types)
+    public function getIteratorWithout($types): RuleSetIterator
     {
         if (!\is_array($types)) {
-            $types = array($types);
+            $types = [$types];
         }
 
         $rules = $this->getRules();
@@ -178,18 +163,14 @@ class RuleSet implements \IteratorAggregate, \Countable
     }
 
     /** @return array{0: 0, 1: 1, 2: 4} */
-    public function getTypes()
+    public function getTypes(): array
     {
         $types = self::$types;
 
         return array_keys($types);
     }
 
-    /**
-     * @param bool $isVerbose
-     * @return string
-     */
-    public function getPrettyString(RepositorySet $repositorySet = null, Request $request = null, Pool $pool = null, $isVerbose = false)
+    public function getPrettyString(?RepositorySet $repositorySet = null, ?Request $request = null, ?Pool $pool = null, bool $isVerbose = false): string
     {
         $string = "\n";
         foreach ($this->rules as $type => $rules) {
@@ -203,7 +184,7 @@ class RuleSet implements \IteratorAggregate, \Countable
         return $string;
     }
 
-    public function __toString()
+    public function __toString(): string
     {
         return $this->getPrettyString();
     }
