@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -16,6 +16,7 @@ use Composer\DependencyResolver\Transaction;
 use Composer\Installer\InstallerEvent;
 use Composer\IO\IOInterface;
 use Composer\Composer;
+use Composer\PartialComposer;
 use Composer\Pcre\Preg;
 use Composer\Util\Platform;
 use Composer\DependencyResolver\Operation\OperationInterface;
@@ -33,7 +34,7 @@ use Symfony\Component\Process\ExecutableFinder;
  * The Event Dispatcher.
  *
  * Example in command:
- *     $dispatcher = new EventDispatcher($this->getComposer(), $this->getApplication()->getIO());
+ *     $dispatcher = new EventDispatcher($this->requireComposer(), $this->getApplication()->getIO());
  *     // ...
  *     $dispatcher->dispatch(ScriptEvents::POST_INSTALL_CMD);
  *     // ...
@@ -44,7 +45,7 @@ use Symfony\Component\Process\ExecutableFinder;
  */
 class EventDispatcher
 {
-    /** @var Composer */
+    /** @var PartialComposer */
     protected $composer;
     /** @var IOInterface */
     protected $io;
@@ -53,7 +54,7 @@ class EventDispatcher
     /** @var ProcessExecutor */
     protected $process;
     /** @var array<string, array<int, array<callable|string>>> */
-    protected $listeners = array();
+    protected $listeners = [];
     /** @var bool */
     protected $runScripts = true;
     /** @var list<string> */
@@ -62,25 +63,24 @@ class EventDispatcher
     /**
      * Constructor.
      *
-     * @param Composer        $composer The composer instance
+     * @param PartialComposer $composer The composer instance
      * @param IOInterface     $io       The IOInterface instance
      * @param ProcessExecutor $process
      */
-    public function __construct(Composer $composer, IOInterface $io, ProcessExecutor $process = null)
+    public function __construct(PartialComposer $composer, IOInterface $io, ?ProcessExecutor $process = null)
     {
         $this->composer = $composer;
         $this->io = $io;
-        $this->process = $process ?: new ProcessExecutor($io);
-        $this->eventStack = array();
+        $this->process = $process ?? new ProcessExecutor($io);
+        $this->eventStack = [];
     }
 
     /**
      * Set whether script handlers are active or not
      *
-     * @param bool $runScripts
      * @return $this
      */
-    public function setRunScripts($runScripts = true)
+    public function setRunScripts(bool $runScripts = true): self
     {
         $this->runScripts = (bool) $runScripts;
 
@@ -90,14 +90,17 @@ class EventDispatcher
     /**
      * Dispatch an event
      *
-     * @param  string $eventName An event name
-     * @param  Event  $event
-     * @return int    return code of the executed script if any, for php scripts a false return
+     * @param  string|null $eventName The event name, required if no $event is provided
+     * @param  Event       $event An event instance, required if no $eventName is provided
+     * @return int         return code of the executed script if any, for php scripts a false return
      *                          value is changed to 1, anything else to 0
      */
-    public function dispatch($eventName, Event $event = null)
+    public function dispatch(?string $eventName, ?Event $event = null): int
     {
         if (null === $event) {
+            if (null === $eventName) {
+                throw new \InvalidArgumentException('If no $event is passed in to '.__METHOD__.' you have to pass in an $eventName, got null.');
+            }
             $event = new Event($eventName);
         }
 
@@ -108,14 +111,15 @@ class EventDispatcher
      * Dispatch a script event.
      *
      * @param  string               $eventName      The constant in ScriptEvents
-     * @param  bool                 $devMode
      * @param  array<int, mixed>    $additionalArgs Arguments passed by the user
      * @param  array<string, mixed> $flags          Optional flags to pass data not as argument
      * @return int                                  return code of the executed script if any, for php scripts a false return
      *                                              value is changed to 1, anything else to 0
      */
-    public function dispatchScript($eventName, $devMode = false, $additionalArgs = array(), $flags = array())
+    public function dispatchScript(string $eventName, bool $devMode = false, array $additionalArgs = [], array $flags = []): int
     {
+        assert($this->composer instanceof Composer, new \LogicException('This should only be reached with a fully loaded Composer'));
+
         return $this->doDispatch(new Script\Event($eventName, $this->composer, $this->io, $devMode, $additionalArgs, $flags));
     }
 
@@ -131,8 +135,10 @@ class EventDispatcher
      * @return int return code of the executed script if any, for php scripts a false return
      *             value is changed to 1, anything else to 0
      */
-    public function dispatchPackageEvent($eventName, $devMode, RepositoryInterface $localRepo, array $operations, OperationInterface $operation)
+    public function dispatchPackageEvent(string $eventName, bool $devMode, RepositoryInterface $localRepo, array $operations, OperationInterface $operation): int
     {
+        assert($this->composer instanceof Composer, new \LogicException('This should only be reached with a fully loaded Composer'));
+
         return $this->doDispatch(new PackageEvent($eventName, $this->composer, $this->io, $devMode, $localRepo, $operations, $operation));
     }
 
@@ -147,8 +153,10 @@ class EventDispatcher
      * @return int return code of the executed script if any, for php scripts a false return
      *             value is changed to 1, anything else to 0
      */
-    public function dispatchInstallerEvent($eventName, $devMode, $executeOperations, Transaction $transaction)
+    public function dispatchInstallerEvent(string $eventName, bool $devMode, bool $executeOperations, Transaction $transaction): int
     {
+        assert($this->composer instanceof Composer, new \LogicException('This should only be reached with a fully loaded Composer'));
+
         return $this->doDispatch(new InstallerEvent($eventName, $this->composer, $this->io, $devMode, $executeOperations, $transaction));
     }
 
@@ -189,7 +197,7 @@ class EventDispatcher
                     if (is_array($callable) && (is_string($callable[0]) || is_object($callable[0])) && is_string($callable[1])) {
                         $this->io->writeError(sprintf('> %s: %s', $event->getName(), (is_object($callable[0]) ? get_class($callable[0]) : $callable[0]).'->'.$callable[1]), true, IOInterface::VERBOSE);
                     }
-                    $return = false === call_user_func($callable, $event) ? 1 : 0;
+                    $return = false === $callable($event) ? 1 : 0;
                 } elseif ($this->isComposerScript($callable)) {
                     $this->io->writeError(sprintf('> %s: %s', $event->getName(), $callable), true, IOInterface::VERBOSE);
 
@@ -242,8 +250,15 @@ class EventDispatcher
                         throw $e;
                     }
                 } else {
-                    $args = implode(' ', array_map(array('Composer\Util\ProcessExecutor', 'escape'), $event->getArguments()));
-                    $exec = $callable . ($args === '' ? '' : ' '.$args);
+                    $args = implode(' ', array_map(['Composer\Util\ProcessExecutor', 'escape'], $event->getArguments()));
+
+                    // @putenv does not receive arguments
+                    if (strpos($callable, '@putenv ') === 0) {
+                        $exec = $callable;
+                    } else {
+                        $exec = $callable . ($args === '' ? '' : ' '.$args);
+                    }
+
                     if ($this->io->isVerbose()) {
                         $this->io->writeError(sprintf('> %s: %s', $event->getName(), $exec));
                     } elseif ($event->getName() !== '__exec_command') {
@@ -266,7 +281,7 @@ class EventDispatcher
                         if (false === strpos($exec, '=')) {
                             Platform::clearEnv(substr($exec, 8));
                         } else {
-                            list($var, $value) = explode('=', substr($exec, 8), 2);
+                            [$var, $value] = explode('=', substr($exec, 8), 2);
                             Platform::putEnv($var, $value);
                         }
 
@@ -275,7 +290,7 @@ class EventDispatcher
                     if (strpos($exec, '@php ') === 0) {
                         $pathAndArgs = substr($exec, 5);
                         if (Platform::isWindows()) {
-                            $pathAndArgs = Preg::replaceCallback('{^\S+}', function ($path) {
+                            $pathAndArgs = Preg::replaceCallback('{^\S+}', static function ($path) {
                                 return str_replace('/', '\\', $path[0]);
                             }, $pathAndArgs);
                         }
@@ -297,7 +312,7 @@ class EventDispatcher
                         }
 
                         if (Platform::isWindows()) {
-                            $exec = Preg::replaceCallback('{^\S+}', function ($path) {
+                            $exec = Preg::replaceCallback('{^\S+}', static function ($path) {
                                 return str_replace('/', '\\', $path[0]);
                             }, $exec);
                         }
@@ -323,27 +338,14 @@ class EventDispatcher
                     break;
                 }
             }
-        } catch (\Exception $e) { // TODO Composer 2.2 turn all this into a finally
+        } finally {
             $this->popEvent();
-
-            throw $e;
-        } catch (\Throwable $e) {
-            $this->popEvent();
-
-            throw $e;
         }
 
-        $this->popEvent();
-
         return $returnMax;
     }
 
-    /**
-     * @param string $exec
-     *
-     * @return int
-     */
-    protected function executeTty($exec)
+    protected function executeTty(string $exec): int
     {
         if ($this->io->isInteractive()) {
             return $this->process->executeTty($exec);
@@ -352,10 +354,7 @@ class EventDispatcher
         return $this->process->execute($exec);
     }
 
-    /**
-     * @return string
-     */
-    protected function getPhpExecCommand()
+    protected function getPhpExecCommand(): string
     {
         $finder = new PhpExecutableFinder();
         $phpPath = $finder->find(false);
@@ -372,13 +371,11 @@ class EventDispatcher
     }
 
     /**
-     * @param string $className
-     * @param string $methodName
      * @param Event  $event      Event invoking the PHP callable
      *
      * @return mixed
      */
-    protected function executeEventPhpScript($className, $methodName, Event $event)
+    protected function executeEventPhpScript(string $className, string $methodName, Event $event)
     {
         if ($this->io->isVerbose()) {
             $this->io->writeError(sprintf('> %s: %s::%s', $event->getName(), $className, $methodName));
@@ -392,23 +389,19 @@ class EventDispatcher
     /**
      * Add a listener for a particular event
      *
-     * @param string   $eventName The event name - typically a constant
-     * @param callable $listener  A callable expecting an event argument
-     * @param int      $priority  A higher value represents a higher priority
-     *
-     * @return void
+     * @param string          $eventName The event name - typically a constant
+     * @param callable|string $listener  A callable expecting an event argument, or a command string to be executed (same as a composer.json "scripts" entry)
+     * @param int             $priority  A higher value represents a higher priority
      */
-    public function addListener($eventName, $listener, $priority = 0)
+    public function addListener(string $eventName, $listener, int $priority = 0): void
     {
         $this->listeners[$eventName][$priority][] = $listener;
     }
 
     /**
      * @param callable|object $listener A callable or an object instance for which all listeners should be removed
-     *
-     * @return void
      */
-    public function removeListener($listener)
+    public function removeListener($listener): void
     {
         foreach ($this->listeners as $eventName => $priorities) {
             foreach ($priorities as $priority => $listeners) {
@@ -425,21 +418,17 @@ class EventDispatcher
      * Adds object methods as listeners for the events in getSubscribedEvents
      *
      * @see EventSubscriberInterface
-     *
-     * @param EventSubscriberInterface $subscriber
-     *
-     * @return void
      */
-    public function addSubscriber(EventSubscriberInterface $subscriber)
+    public function addSubscriber(EventSubscriberInterface $subscriber): void
     {
         foreach ($subscriber->getSubscribedEvents() as $eventName => $params) {
             if (is_string($params)) {
-                $this->addListener($eventName, array($subscriber, $params));
+                $this->addListener($eventName, [$subscriber, $params]);
             } elseif (is_string($params[0])) {
-                $this->addListener($eventName, array($subscriber, $params[0]), isset($params[1]) ? $params[1] : 0);
+                $this->addListener($eventName, [$subscriber, $params[0]], $params[1] ?? 0);
             } else {
                 foreach ($params as $listener) {
-                    $this->addListener($eventName, array($subscriber, $listener[0]), isset($listener[1]) ? $listener[1] : 0);
+                    $this->addListener($eventName, [$subscriber, $listener[0]], $listener[1] ?? 0);
                 }
             }
         }
@@ -448,31 +437,27 @@ class EventDispatcher
     /**
      * Retrieves all listeners for a given event
      *
-     * @param  Event $event
      * @return array<callable|string> All listeners: callables and scripts
      */
-    protected function getListeners(Event $event)
+    protected function getListeners(Event $event): array
     {
-        $scriptListeners = $this->runScripts ? $this->getScriptListeners($event) : array();
+        $scriptListeners = $this->runScripts ? $this->getScriptListeners($event) : [];
 
         if (!isset($this->listeners[$event->getName()][0])) {
-            $this->listeners[$event->getName()][0] = array();
+            $this->listeners[$event->getName()][0] = [];
         }
         krsort($this->listeners[$event->getName()]);
 
         $listeners = $this->listeners;
         $listeners[$event->getName()][0] = array_merge($listeners[$event->getName()][0], $scriptListeners);
 
-        return call_user_func_array('array_merge', $listeners[$event->getName()]);
+        return array_merge(...$listeners[$event->getName()]);
     }
 
     /**
      * Checks if an event has listeners registered
-     *
-     * @param  Event $event
-     * @return bool
      */
-    public function hasEventListeners(Event $event)
+    public function hasEventListeners(Event $event): bool
     {
         $listeners = $this->getListeners($event);
 
@@ -485,15 +470,17 @@ class EventDispatcher
      * @param  Event $event Event object
      * @return string[] Listeners
      */
-    protected function getScriptListeners(Event $event)
+    protected function getScriptListeners(Event $event): array
     {
         $package = $this->composer->getPackage();
         $scripts = $package->getScripts();
 
         if (empty($scripts[$event->getName()])) {
-            return array();
+            return [];
         }
 
+        assert($this->composer instanceof Composer, new \LogicException('This should only be reached with a fully loaded Composer'));
+
         if ($this->loader) {
             $this->loader->unregister();
         }
@@ -514,22 +501,16 @@ class EventDispatcher
 
     /**
      * Checks if string given references a class path and method
-     *
-     * @param  string $callable
-     * @return bool
      */
-    protected function isPhpScript($callable)
+    protected function isPhpScript(string $callable): bool
     {
         return false === strpos($callable, ' ') && false !== strpos($callable, '::');
     }
 
     /**
      * Checks if string given references a composer run-script
-     *
-     * @param  string $callable
-     * @return bool
      */
-    protected function isComposerScript($callable)
+    protected function isComposerScript(string $callable): bool
     {
         return strpos($callable, '@') === 0 && strpos($callable, '@php ') !== 0 && strpos($callable, '@putenv ') !== 0;
     }
@@ -537,11 +518,9 @@ class EventDispatcher
     /**
      * Push an event to the stack of active event
      *
-     * @param  Event             $event
      * @throws \RuntimeException
-     * @return int
      */
-    protected function pushEvent(Event $event)
+    protected function pushEvent(Event $event): int
     {
         $eventName = $event->getName();
         if (in_array($eventName, $this->eventStack)) {
@@ -553,21 +532,20 @@ class EventDispatcher
 
     /**
      * Pops the active event from the stack
-     *
-     * @return string|null
      */
-    protected function popEvent()
+    protected function popEvent(): ?string
     {
         return array_pop($this->eventStack);
     }
 
-    /**
-     * @return void
-     */
-    private function ensureBinDirIsInPath()
+    private function ensureBinDirIsInPath(): void
     {
         $pathEnv = 'PATH';
-        if (false === Platform::getEnv('PATH') && false !== Platform::getEnv('Path')) {
+
+        // checking if only Path and not PATH is set then we probably need to update the Path env
+        // on Windows getenv is case-insensitive so we cannot check it via Platform::getEnv and
+        // we need to check in $_SERVER directly
+        if (!isset($_SERVER[$pathEnv]) && isset($_SERVER['Path'])) {
             $pathEnv = 'Path';
         }
 
@@ -575,7 +553,7 @@ class EventDispatcher
         $binDir = $this->composer->getConfig()->get('bin-dir');
         if (is_dir($binDir)) {
             $binDir = realpath($binDir);
-            $pathValue = Platform::getEnv($pathEnv);
+            $pathValue = (string) Platform::getEnv($pathEnv);
             if (!Preg::isMatch('{(^|'.PATH_SEPARATOR.')'.preg_quote($binDir).'($|'.PATH_SEPARATOR.')}', $pathValue)) {
                 Platform::putEnv($pathEnv, $binDir.PATH_SEPARATOR.$pathValue);
             }
