@@ -27,6 +27,7 @@ use Composer\DependencyResolver\Solver;
 use Composer\DependencyResolver\SolverProblemsException;
 use Composer\DependencyResolver\PolicyInterface;
 use Composer\Downloader\DownloadManager;
+use Composer\Downloader\TransportException;
 use Composer\EventDispatcher\EventDispatcher;
 use Composer\Filter\PlatformRequirementFilter\IgnoreListPlatformRequirementFilter;
 use Composer\Filter\PlatformRequirementFilter\PlatformRequirementFilterFactory;
@@ -60,6 +61,8 @@ use Composer\Repository\RepositoryInterface;
 use Composer\Repository\RepositoryManager;
 use Composer\Repository\LockArrayRepository;
 use Composer\Script\ScriptEvents;
+use Composer\Semver\Constraint\ConstraintInterface;
+use Composer\Advisory\Auditor;
 use Composer\Util\Platform;
 
 /**
@@ -162,6 +165,10 @@ class Installer
     protected $writeLock;
     /** @var bool */
     protected $executeOperations = true;
+    /** @var bool */
+    protected $audit = true;
+    /** @var Auditor::FORMAT_* */
+    protected $auditFormat = Auditor::FORMAT_SUMMARY;
 
     /** @var bool */
     protected $updateMirrors = false;
@@ -189,18 +196,13 @@ class Installer
      */
     protected $additionalFixedRepository;
 
+    /** @var array<string, ConstraintInterface> */
+    protected $temporaryConstraints = [];
+
     /**
      * Constructor
      *
-     * @param IOInterface          $io
-     * @param Config               $config
      * @param RootPackageInterface&BasePackage $package
-     * @param DownloadManager      $downloadManager
-     * @param RepositoryManager    $repositoryManager
-     * @param Locker               $locker
-     * @param InstallationManager  $installationManager
-     * @param EventDispatcher      $eventDispatcher
-     * @param AutoloadGenerator    $autoloadGenerator
      */
     public function __construct(IOInterface $io, Config $config, RootPackageInterface $package, DownloadManager $downloadManager, RepositoryManager $repositoryManager, Locker $locker, InstallationManager $installationManager, EventDispatcher $eventDispatcher, AutoloadGenerator $autoloadGenerator)
     {
@@ -295,11 +297,11 @@ class Installer
         }
 
         if ($this->update) {
-            $installedRepo = new InstalledRepository(array(
+            $installedRepo = new InstalledRepository([
                 $this->locker->getLockedRepository($this->devMode),
                 $this->createPlatformRepo(false),
                 new RootPackageRepository(clone $this->package),
-            ));
+            ]);
             if ($isFreshInstall) {
                 $this->suggestedPackagesReporter->addSuggestionsFromPackage($this->package);
             }
@@ -355,7 +357,7 @@ class Installer
             }
         }
         if ($fundingCount > 0) {
-            $this->io->writeError(array(
+            $this->io->writeError([
                 sprintf(
                     "<info>%d package%s you are using %s looking for funding.</info>",
                     $fundingCount,
@@ -363,7 +365,7 @@ class Installer
                     1 === $fundingCount ? 'is' : 'are'
                 ),
                 '<info>Use the `composer fund` command to find out more!</info>',
-            ));
+            ]);
         }
 
         if ($this->runScripts) {
@@ -377,13 +379,37 @@ class Installer
             gc_enable();
         }
 
+        if ($this->audit) {
+            if ($this->update && !$this->install) {
+                $packages = $lockedRepository->getCanonicalPackages();
+                $target = 'locked';
+            } else {
+                $packages = $localRepo->getCanonicalPackages();
+                $target = 'installed';
+            }
+            if (count($packages) > 0) {
+                try {
+                    $auditor = new Auditor();
+                    $repoSet = new RepositorySet();
+                    foreach ($this->repositoryManager->getRepositories() as $repo) {
+                        $repoSet->addRepository($repo);
+                    }
+                    $auditor->audit($this->io, $repoSet, $packages, $this->auditFormat);
+                } catch (TransportException $e) {
+                    $this->io->error('Failed to audit '.$target.' packages.');
+                    if ($this->io->isVerbose()) {
+                        $this->io->error('['.get_class($e).'] '.$e->getMessage());
+                    }
+                }
+            } else {
+                $this->io->writeError('No '.$target.' packages - skipping audit.');
+            }
+        }
+
         return 0;
     }
 
     /**
-     * @param bool $doInstall
-     *
-     * @return int
      * @phpstan-return self::ERROR_*
      */
     protected function doUpdate(InstalledRepositoryInterface $localRepo, bool $doInstall): int
@@ -482,9 +508,9 @@ class Installer
         $platformReqs = $this->extractPlatformRequirements($this->package->getRequires());
         $platformDevReqs = $this->extractPlatformRequirements($this->package->getDevRequires());
 
-        $installsUpdates = $uninstalls = array();
+        $installsUpdates = $uninstalls = [];
         if ($lockTransaction->getOperations()) {
-            $installNames = $updateNames = $uninstallNames = array();
+            $installNames = $updateNames = $uninstallNames = [];
             foreach ($lockTransaction->getOperations() as $operation) {
                 if ($operation instanceof InstallOperation) {
                     $installsUpdates[] = $operation;
@@ -493,8 +519,8 @@ class Installer
                     // when mirrors/metadata from a package gets updated we do not want to list it as an
                     // update in the output as it is only an internal lock file metadata update
                     if ($this->updateMirrors
-                        && $operation->getInitialPackage()->getName() == $operation->getTargetPackage()->getName()
-                        && $operation->getInitialPackage()->getVersion() == $operation->getTargetPackage()->getVersion()
+                        && $operation->getInitialPackage()->getName() === $operation->getTargetPackage()->getName()
+                        && $operation->getInitialPackage()->getVersion() === $operation->getTargetPackage()->getVersion()
                     ) {
                         continue;
                     }
@@ -529,7 +555,7 @@ class Installer
             }
         }
 
-        $sortByName = function ($a, $b): int {
+        $sortByName = static function ($a, $b): int {
             if ($a instanceof UpdateOperation) {
                 $a = $a->getTargetPackage()->getName();
             } else {
@@ -568,7 +594,7 @@ class Installer
             $this->package->getStabilityFlags(),
             $this->preferStable || $this->package->getPreferStable(),
             $this->preferLowest,
-            $this->config->get('platform') ?: array(),
+            $this->config->get('platform') ?: [],
             $this->writeLock && $this->executeOperations
         );
         if ($updatedLock && $this->writeLock && $this->executeOperations) {
@@ -599,18 +625,16 @@ class Installer
      *
      * @param array<int, array<string, string>> $aliases
      *
-     * @return int
-     *
      * @phpstan-param list<array{package: string, version: string, alias: string, alias_normalized: string}> $aliases
      * @phpstan-return self::ERROR_*
      */
-    protected function extractDevPackages(LockTransaction $lockTransaction, PlatformRepository $platformRepo, array $aliases, PolicyInterface $policy, LockArrayRepository $lockedRepository = null): int
+    protected function extractDevPackages(LockTransaction $lockTransaction, PlatformRepository $platformRepo, array $aliases, PolicyInterface $policy, ?LockArrayRepository $lockedRepository = null): int
     {
         if (!$this->package->getDevRequires()) {
             return 0;
         }
 
-        $resultRepo = new ArrayRepository(array());
+        $resultRepo = new ArrayRepository([]);
         $loader = new ArrayLoader(null, true);
         $dumper = new ArrayDumper();
         foreach ($lockTransaction->getNewLockPackages(false) as $pkg) {
@@ -650,7 +674,6 @@ class Installer
     }
 
     /**
-     * @param  InstalledRepositoryInterface $localRepo
      * @param  bool                         $alreadySolved Whether the function is called as part of an update command or independently
      * @return int                          exit code
      * @phpstan-return self::ERROR_*
@@ -672,7 +695,7 @@ class Installer
             // creating repository set
             $policy = $this->createPolicy(false);
             // use aliases from lock file only, so empty root aliases here
-            $repositorySet = $this->createRepositorySet(false, $platformRepo, array(), $lockedRepository);
+            $repositorySet = $this->createRepositorySet(false, $platformRepo, [], $lockedRepository);
             $repositorySet->addRepository($lockedRepository);
 
             // creating requirements request
@@ -727,7 +750,7 @@ class Installer
         }
 
         if ($localRepoTransaction->getOperations()) {
-            $installs = $updates = $uninstalls = array();
+            $installs = $updates = $uninstalls = [];
             foreach ($localRepoTransaction->getOperations() as $operation) {
                 if ($operation instanceof InstallOperation) {
                     $installs[] = $operation->getPackage()->getPrettyName().':'.$operation->getPackage()->getFullPrettyVersion();
@@ -773,32 +796,23 @@ class Installer
         return 0;
     }
 
-    /**
-     * @param bool $forUpdate
-     *
-     * @return PlatformRepository
-     */
     protected function createPlatformRepo(bool $forUpdate): PlatformRepository
     {
         if ($forUpdate) {
-            $platformOverrides = $this->config->get('platform') ?: array();
+            $platformOverrides = $this->config->get('platform') ?: [];
         } else {
             $platformOverrides = $this->locker->getPlatformOverrides();
         }
 
-        return new PlatformRepository(array(), $platformOverrides);
+        return new PlatformRepository([], $platformOverrides);
     }
 
     /**
-     * @param  bool                              $forUpdate
      * @param  array<int, array<string, string>> $rootAliases
-     * @param  RepositoryInterface|null          $lockedRepository
-     *
-     * @return RepositorySet
      *
      * @phpstan-param list<array{package: string, version: string, alias: string, alias_normalized: string}> $rootAliases
      */
-    private function createRepositorySet(bool $forUpdate, PlatformRepository $platformRepo, array $rootAliases = array(), ?RepositoryInterface $lockedRepository = null): RepositorySet
+    private function createRepositorySet(bool $forUpdate, PlatformRepository $platformRepo, array $rootAliases = [], ?RepositoryInterface $lockedRepository = null): RepositorySet
     {
         if ($forUpdate) {
             $minimumStability = $this->package->getMinimumStability();
@@ -809,7 +823,7 @@ class Installer
             $minimumStability = $this->locker->getMinimumStability();
             $stabilityFlags = $this->locker->getStabilityFlags();
 
-            $requires = array();
+            $requires = [];
             foreach ($lockedRepository->getPackages() as $package) {
                 $constraint = new Constraint('=', $package->getVersion());
                 $constraint->setPrettyString($package->getPrettyVersion());
@@ -817,7 +831,7 @@ class Installer
             }
         }
 
-        $rootRequires = array();
+        $rootRequires = [];
         foreach ($requires as $req => $constraint) {
             if ($constraint instanceof Link) {
                 $constraint = $constraint->getConstraint();
@@ -832,12 +846,12 @@ class Installer
         }
 
         $this->fixedRootPackage = clone $this->package;
-        $this->fixedRootPackage->setRequires(array());
-        $this->fixedRootPackage->setDevRequires(array());
+        $this->fixedRootPackage->setRequires([]);
+        $this->fixedRootPackage->setDevRequires([]);
 
         $stabilityFlags[$this->package->getName()] = BasePackage::$stabilities[VersionParser::parseStability($this->package->getVersion())];
 
-        $repositorySet = new RepositorySet($minimumStability, $stabilityFlags, $rootAliases, $this->package->getReferences(), $rootRequires);
+        $repositorySet = new RepositorySet($minimumStability, $stabilityFlags, $rootAliases, $this->package->getReferences(), $rootRequires, $this->temporaryConstraints);
         $repositorySet->addRepository(new RootPackageRepository($this->fixedRootPackage));
         $repositorySet->addRepository($platformRepo);
         if ($this->additionalFixedRepository) {
@@ -847,7 +861,7 @@ class Installer
             if ($additionalFixedRepositories instanceof CompositeRepository) {
                 $additionalFixedRepositories = $additionalFixedRepositories->getRepositories();
             } else {
-                $additionalFixedRepositories = array($additionalFixedRepositories);
+                $additionalFixedRepositories = [$additionalFixedRepositories];
             }
             foreach ($additionalFixedRepositories as $additionalFixedRepository) {
                 if ($additionalFixedRepository instanceof InstalledRepository || $additionalFixedRepository instanceof InstalledRepositoryInterface) {
@@ -862,11 +876,6 @@ class Installer
         return $repositorySet;
     }
 
-    /**
-     * @param bool $forUpdate
-     *
-     * @return DefaultPolicy
-     */
     private function createPolicy(bool $forUpdate): DefaultPolicy
     {
         $preferStable = null;
@@ -889,9 +898,8 @@ class Installer
 
     /**
      * @param RootPackageInterface&BasePackage $rootPackage
-     * @return Request
      */
-    private function createRequest(RootPackageInterface $rootPackage, PlatformRepository $platformRepo, LockArrayRepository $lockedRepository = null): Request
+    private function createRequest(RootPackageInterface $rootPackage, PlatformRepository $platformRepo, ?LockArrayRepository $lockedRepository = null): Request
     {
         $request = new Request($lockedRepository);
 
@@ -922,17 +930,11 @@ class Installer
         return $request;
     }
 
-    /**
-     * @param LockArrayRepository|null $lockedRepository
-     * @param bool                     $includeDevRequires
-     *
-     * @return void
-     */
-    private function requirePackagesForUpdate(Request $request, LockArrayRepository $lockedRepository = null, bool $includeDevRequires = true): void
+    private function requirePackagesForUpdate(Request $request, ?LockArrayRepository $lockedRepository = null, bool $includeDevRequires = true): void
     {
         // if we're updating mirrors we want to keep exactly the same versions installed which are in the lock file, but we want current remote metadata
         if ($this->updateMirrors) {
-            $excludedPackages = array();
+            $excludedPackages = [];
             if (!$includeDevRequires) {
                 $excludedPackages = array_flip($this->locker->getDevPackageNames());
             }
@@ -956,8 +958,6 @@ class Installer
     }
 
     /**
-     * @param bool $forUpdate
-     *
      * @return array<int, array<string, string>>
      *
      * @phpstan-return list<array{package: string, version: string, alias: string, alias_normalized: string}>
@@ -980,7 +980,7 @@ class Installer
      */
     private function extractPlatformRequirements(array $links): array
     {
-        $platformReqs = array();
+        $platformReqs = [];
         foreach ($links as $link) {
             if (PlatformRepository::isPlatformPackage($link->getTarget())) {
                 $platformReqs[$link->getTarget()] = $link->getPrettyConstraint();
@@ -994,12 +994,10 @@ class Installer
      * Replace local repositories with InstalledArrayRepository instances
      *
      * This is to prevent any accidental modification of the existing repos on disk
-     *
-     * @return void
      */
     private function mockLocalRepositories(RepositoryManager $rm): void
     {
-        $packages = array();
+        $packages = [];
         foreach ($rm->getLocalRepository()->getPackages() as $package) {
             $packages[(string) $package] = clone $package;
         }
@@ -1015,9 +1013,6 @@ class Installer
         );
     }
 
-    /**
-     * @return PoolOptimizer|null
-     */
     private function createPoolOptimizer(PolicyInterface $policy): ?PoolOptimizer
     {
         // Not the best architectural decision here, would need to be able
@@ -1035,8 +1030,6 @@ class Installer
     /**
      * Create Installer
      *
-     * @param  IOInterface $io
-     * @param  Composer    $composer
      * @return Installer
      */
     public static function create(IOInterface $io, Composer $composer): self
@@ -1055,7 +1048,6 @@ class Installer
     }
 
     /**
-     * @param  RepositoryInterface $additionalFixedRepository
      * @return $this
      */
     public function setAdditionalFixedRepository(RepositoryInterface $additionalFixedRepository): self
@@ -1065,10 +1057,20 @@ class Installer
         return $this;
     }
 
+    /**
+     * @param array<string, ConstraintInterface> $constraints
+     * @return Installer
+     */
+    public function setTemporaryConstraints(array $constraints): self
+    {
+        $this->temporaryConstraints = $constraints;
+
+        return $this;
+    }
+
     /**
      * Whether to run in drymode or not
      *
-     * @param  bool      $dryRun
      * @return Installer
      */
     public function setDryRun(bool $dryRun = true): self
@@ -1080,8 +1082,6 @@ class Installer
 
     /**
      * Checks, if this is a dry run (simulation mode).
-     *
-     * @return bool
      */
     public function isDryRun(): bool
     {
@@ -1091,7 +1091,6 @@ class Installer
     /**
      * prefer source installation
      *
-     * @param  bool      $preferSource
      * @return Installer
      */
     public function setPreferSource(bool $preferSource = true): self
@@ -1104,7 +1103,6 @@ class Installer
     /**
      * prefer dist installation
      *
-     * @param  bool      $preferDist
      * @return Installer
      */
     public function setPreferDist(bool $preferDist = true): self
@@ -1117,7 +1115,6 @@ class Installer
     /**
      * Whether or not generated autoloader are optimized
      *
-     * @param  bool      $optimizeAutoloader
      * @return Installer
      */
     public function setOptimizeAutoloader(bool $optimizeAutoloader): self
@@ -1136,7 +1133,6 @@ class Installer
      * Whether or not generated autoloader considers the class map
      * authoritative.
      *
-     * @param  bool      $classMapAuthoritative
      * @return Installer
      */
     public function setClassMapAuthoritative(bool $classMapAuthoritative): self
@@ -1153,8 +1149,6 @@ class Installer
     /**
      * Whether or not generated autoloader considers APCu caching.
      *
-     * @param  bool        $apcuAutoloader
-     * @param  string|null $apcuAutoloaderPrefix
      * @return Installer
      */
     public function setApcuAutoloader(bool $apcuAutoloader, ?string $apcuAutoloaderPrefix = null): self
@@ -1168,7 +1162,6 @@ class Installer
     /**
      * update packages
      *
-     * @param  bool      $update
      * @return Installer
      */
     public function setUpdate(bool $update): self
@@ -1181,7 +1174,6 @@ class Installer
     /**
      * Allows disabling the install step after an update
      *
-     * @param  bool      $install
      * @return Installer
      */
     public function setInstall(bool $install): self
@@ -1194,7 +1186,6 @@ class Installer
     /**
      * enables dev packages
      *
-     * @param  bool      $devMode
      * @return Installer
      */
     public function setDevMode(bool $devMode = true): self
@@ -1209,7 +1200,6 @@ class Installer
      *
      * This is disabled implicitly when enabling dryRun
      *
-     * @param  bool      $dumpAutoloader
      * @return Installer
      */
     public function setDumpAutoloader(bool $dumpAutoloader = true): self
@@ -1224,7 +1214,6 @@ class Installer
      *
      * This is disabled implicitly when enabling dryRun
      *
-     * @param  bool      $runScripts
      * @return Installer
      * @deprecated Use setRunScripts(false) on the EventDispatcher instance being injected instead
      */
@@ -1238,7 +1227,6 @@ class Installer
     /**
      * set the config instance
      *
-     * @param  Config    $config
      * @return Installer
      */
     public function setConfig(Config $config): self
@@ -1251,7 +1239,6 @@ class Installer
     /**
      * run in verbose mode
      *
-     * @param  bool      $verbose
      * @return Installer
      */
     public function setVerbose(bool $verbose = true): self
@@ -1263,8 +1250,6 @@ class Installer
 
     /**
      * Checks, if running in verbose mode.
-     *
-     * @return bool
      */
     public function isVerbose(): bool
     {
@@ -1292,7 +1277,6 @@ class Installer
     }
 
     /**
-     * @param PlatformRequirementFilterInterface $platformRequirementFilter
      * @return Installer
      */
     public function setPlatformRequirementFilter(PlatformRequirementFilterInterface $platformRequirementFilter): self
@@ -1305,7 +1289,6 @@ class Installer
     /**
      * Update the lock file to the exact same versions and references but use current remote metadata like URLs and mirror info
      *
-     * @param  bool      $updateMirrors
      * @return Installer
      */
     public function setUpdateMirrors(bool $updateMirrors): self
@@ -1341,7 +1324,7 @@ class Installer
      */
     public function setUpdateAllowTransitiveDependencies(int $updateAllowTransitiveDependencies): self
     {
-        if (!in_array($updateAllowTransitiveDependencies, array(Request::UPDATE_ONLY_LISTED, Request::UPDATE_LISTED_WITH_TRANSITIVE_DEPS_NO_ROOT_REQUIRE, Request::UPDATE_LISTED_WITH_TRANSITIVE_DEPS), true)) {
+        if (!in_array($updateAllowTransitiveDependencies, [Request::UPDATE_ONLY_LISTED, Request::UPDATE_LISTED_WITH_TRANSITIVE_DEPS_NO_ROOT_REQUIRE, Request::UPDATE_LISTED_WITH_TRANSITIVE_DEPS], true)) {
             throw new \RuntimeException("Invalid value for updateAllowTransitiveDependencies supplied");
         }
 
@@ -1353,7 +1336,6 @@ class Installer
     /**
      * Should packages be preferred in a stable version when updating?
      *
-     * @param  bool      $preferStable
      * @return Installer
      */
     public function setPreferStable(bool $preferStable = true): self
@@ -1366,7 +1348,6 @@ class Installer
     /**
      * Should packages be preferred in a lowest version when updating?
      *
-     * @param  bool      $preferLowest
      * @return Installer
      */
     public function setPreferLowest(bool $preferLowest = true): self
@@ -1381,7 +1362,6 @@ class Installer
      *
      * This is disabled implicitly when enabling dryRun
      *
-     * @param  bool      $writeLock
      * @return Installer
      */
     public function setWriteLock(bool $writeLock = true): self
@@ -1396,7 +1376,6 @@ class Installer
      *
      * This is disabled implicitly when enabling dryRun
      *
-     * @param  bool      $executeOperations
      * @return Installer
      */
     public function setExecuteOperations(bool $executeOperations = true): self
@@ -1406,6 +1385,31 @@ class Installer
         return $this;
     }
 
+    /**
+     * Should an audit be run after installation is complete?
+     *
+     * @return Installer
+     */
+    public function setAudit(bool $audit): self
+    {
+        $this->audit = $audit;
+
+        return $this;
+    }
+
+    /**
+     * What format should be used for audit output?
+     *
+     * @param Auditor::FORMAT_* $auditFormat
+     * @return Installer
+     */
+    public function setAuditFormat(string $auditFormat): self
+    {
+        $this->auditFormat = $auditFormat;
+
+        return $this;
+    }
+
     /**
      * Disables plugins.
      *
@@ -1423,7 +1427,6 @@ class Installer
     }
 
     /**
-     * @param  SuggestedPackagesReporter $suggestedPackagesReporter
      * @return Installer
      */
     public function setSuggestedPackagesReporter(SuggestedPackagesReporter $suggestedPackagesReporter): self
