@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -26,13 +26,38 @@ class Platform
     /** @var ?bool */
     private static $isWindowsSubsystemForLinux = null;
 
+    /**
+     * getcwd() equivalent which always returns a string
+     *
+     * @throws \RuntimeException
+     */
+    public static function getCwd(bool $allowEmpty = false): string
+    {
+        $cwd = getcwd();
+
+        // fallback to realpath('') just in case this works but odds are it would break as well if we are in a case where getcwd fails
+        if (false === $cwd) {
+            $cwd = realpath('');
+        }
+
+        // crappy state, assume '' and hopefully relative paths allow things to continue
+        if (false === $cwd) {
+            if ($allowEmpty) {
+                return '';
+            }
+
+            throw new \RuntimeException('Could not determine the current working directory');
+        }
+
+        return $cwd;
+    }
+
     /**
      * getenv() equivalent but reads from the runtime global variables first
      *
-     * @param  string $name
      * @return string|false
      */
-    public static function getEnv($name)
+    public static function getEnv(string $name)
     {
         if (array_key_exists($name, $_SERVER)) {
             return (string) $_SERVER[$name];
@@ -46,12 +71,8 @@ class Platform
 
     /**
      * putenv() equivalent but updates the runtime global variables too
-     *
-     * @param  string $name
-     * @param  string $value
-     * @return void
      */
-    public static function putEnv($name, $value)
+    public static function putEnv(string $name, string $value): void
     {
         $value = (string) $value;
         putenv($name . '=' . $value);
@@ -60,11 +81,8 @@ class Platform
 
     /**
      * putenv('X') equivalent but updates the runtime global variables too
-     *
-     * @param  string $name
-     * @return void
      */
-    public static function clearEnv($name)
+    public static function clearEnv(string $name): void
     {
         putenv($name);
         unset($_SERVER[$name], $_ENV[$name]);
@@ -72,19 +90,16 @@ class Platform
 
     /**
      * Parses tildes and environment variables in paths.
-     *
-     * @param  string $path
-     * @return string
      */
-    public static function expandPath($path)
+    public static function expandPath(string $path): string
     {
         if (Preg::isMatch('#^~[\\/]#', $path)) {
             return self::getUserDirectory() . substr($path, 1);
         }
 
-        return Preg::replaceCallback('#^(\$|(?P<percent>%))(?P<var>\w++)(?(percent)%)(?P<path>.*)#', function ($matches) {
+        return Preg::replaceCallback('#^(\$|(?P<percent>%))(?P<var>\w++)(?(percent)%)(?P<path>.*)#', static function ($matches): string {
             // Treat HOME as an alias for USERPROFILE on Windows for legacy reasons
-            if (Platform::isWindows() && $matches['var'] == 'HOME') {
+            if (Platform::isWindows() && $matches['var'] === 'HOME') {
                 return (Platform::getEnv('HOME') ?: Platform::getEnv('USERPROFILE')) . $matches['path'];
             }
 
@@ -96,7 +111,7 @@ class Platform
      * @throws \RuntimeException If the user home could not reliably be determined
      * @return string            The formal user home as detected from environment parameters
      */
-    public static function getUserDirectory()
+    public static function getUserDirectory(): string
     {
         if (false !== ($home = self::getEnv('HOME'))) {
             return $home;
@@ -118,7 +133,7 @@ class Platform
     /**
      * @return bool Whether the host machine is running on the Windows Subsystem for Linux (WSL)
      */
-    public static function isWindowsSubsystemForLinux()
+    public static function isWindowsSubsystemForLinux(): bool
     {
         if (null === self::$isWindowsSubsystemForLinux) {
             self::$isWindowsSubsystemForLinux = false;
@@ -144,16 +159,15 @@ class Platform
     /**
      * @return bool Whether the host machine is running a Windows OS
      */
-    public static function isWindows()
+    public static function isWindows(): bool
     {
         return \defined('PHP_WINDOWS_VERSION_BUILD');
     }
 
     /**
-     * @param  string $str
      * @return int    return a guaranteed binary length of the string, regardless of silly mbstring configs
      */
-    public static function strlen($str)
+    public static function strlen(string $str): int
     {
         static $useMbString = null;
         if (null === $useMbString) {
@@ -169,17 +183,19 @@ class Platform
 
     /**
      * @param  ?resource $fd Open file descriptor or null to default to STDOUT
-     * @return bool
      */
-    public static function isTty($fd = null)
+    public static function isTty($fd = null): bool
     {
         if ($fd === null) {
             $fd = defined('STDOUT') ? STDOUT : fopen('php://stdout', 'w');
+            if ($fd === false) {
+                return false;
+            }
         }
 
         // detect msysgit/mingw and assume this is a tty because detection
         // does not work correctly, see https://github.com/composer/composer/issues/9690
-        if (in_array(strtoupper(self::getEnv('MSYSTEM') ?: ''), array('MINGW32', 'MINGW64'), true)) {
+        if (in_array(strtoupper(self::getEnv('MSYSTEM') ?: ''), ['MINGW32', 'MINGW64'], true)) {
             return true;
         }
 
@@ -200,9 +216,14 @@ class Platform
     }
 
     /**
-     * @return void
+     * @return bool Whether the current command is for bash completion
      */
-    public static function workaroundFilesystemIssues()
+    public static function isInputCompletionProcess(): bool
+    {
+        return '_complete' === ($_SERVER['argv'][1] ?? null);
+    }
+
+    public static function workaroundFilesystemIssues(): void
     {
         if (self::isVirtualBoxGuest()) {
             usleep(200000);
@@ -213,10 +234,8 @@ class Platform
      * Attempts detection of VirtualBox guest VMs
      *
      * This works based on the process' user being "vagrant", the COMPOSER_RUNTIME_ENV env var being set to "virtualbox", or lsmod showing the virtualbox guest additions are loaded
-     *
-     * @return bool
      */
-    private static function isVirtualBoxGuest()
+    private static function isVirtualBoxGuest(): bool
     {
         if (null === self::$isVirtualBoxGuest) {
             self::$isVirtualBoxGuest = false;
@@ -249,4 +268,16 @@ class Platform
 
         return self::$isVirtualBoxGuest;
     }
+
+    /**
+     * @return 'NUL'|'/dev/null'
+     */
+    public static function getDevNull(): string
+    {
+        if (self::isWindows()) {
+            return 'NUL';
+        }
+
+        return '/dev/null';
+    }
 }
