@@ -19,9 +19,6 @@ final class IgnoreAllPlatformRequirementFilterTest extends TestCase
 {
     /**
      * @dataProvider dataIsIgnored
-     *
-     * @param string $req
-     * @param bool $expectIgnored
      */
     public function testIsIgnored(string $req, bool $expectIgnored): void
     {
@@ -35,9 +32,9 @@ final class IgnoreAllPlatformRequirementFilterTest extends TestCase
      */
     public function dataIsIgnored(): array
     {
-        return array(
-            'php is ignored' => array('php', true),
-            'monolog/monolog is not ignored' => array('monolog/monolog', false),
-        );
+        return [
+            'php is ignored' => ['php', true],
+            'monolog/monolog is not ignored' => ['monolog/monolog', false],
+        ];
     }
 }
