@@ -78,19 +78,19 @@ class BitbucketTest extends TestCase
             ->method('get')
             ->with(
                 Bitbucket::OAUTH2_ACCESS_TOKEN_URL,
-                array(
+                [
                     'retry-auth-failure' => false,
-                    'http' => array(
+                    'http' => [
                         'method' => 'POST',
                         'content' => 'grant_type=client_credentials',
-                    ),
-                )
+                    ],
+                ]
             )
             ->willReturn(
                 new Response(
-                    array('url' => Bitbucket::OAUTH2_ACCESS_TOKEN_URL),
+                    ['url' => Bitbucket::OAUTH2_ACCESS_TOKEN_URL],
                     200,
-                    array(),
+                    [],
                     sprintf(
                         '{"access_token": "%s", "scopes": "repository", "expires_in": 3600, "refresh_token": "refreshtoken", "token_type": "bearer"}',
                         $this->token
@@ -117,14 +117,14 @@ class BitbucketTest extends TestCase
             ->method('get')
             ->with('bitbucket-oauth')
             ->willReturn(
-                array(
-                    $this->origin => array(
+                [
+                    $this->origin => [
                         'access-token' => $this->token,
                         'access-token-expiration' => $this->time + 1800,
                         'consumer-key' => $this->consumer_key,
                         'consumer-secret' => $this->consumer_secret,
-                    ),
-                )
+                    ],
+                ]
             );
 
         $this->assertEquals(
@@ -141,14 +141,14 @@ class BitbucketTest extends TestCase
             ->method('get')
             ->with('bitbucket-oauth')
             ->willReturn(
-                array(
-                    $this->origin => array(
+                [
+                    $this->origin => [
                         'access-token' => 'randomExpiredToken',
                         'access-token-expiration' => $this->time - 400,
                         'consumer-key' => $this->consumer_key,
                         'consumer-secret' => $this->consumer_secret,
-                    ),
-                )
+                    ],
+                ]
             );
 
         $this->io->expects($this->once())
@@ -159,19 +159,19 @@ class BitbucketTest extends TestCase
             ->method('get')
             ->with(
                 Bitbucket::OAUTH2_ACCESS_TOKEN_URL,
-                array(
+                [
                     'retry-auth-failure' => false,
-                    'http' => array(
+                    'http' => [
                         'method' => 'POST',
                         'content' => 'grant_type=client_credentials',
-                    ),
-                )
+                    ],
+                ]
             )
             ->willReturn(
                 new Response(
-                    array('url' => Bitbucket::OAUTH2_ACCESS_TOKEN_URL),
+                    ['url' => Bitbucket::OAUTH2_ACCESS_TOKEN_URL],
                     200,
-                    array(),
+                    [],
                     sprintf(
                         '{"access_token": "%s", "scopes": "repository", "expires_in": 3600, "refresh_token": "refreshtoken", "token_type": "bearer"}',
                         $this->token
@@ -196,24 +196,24 @@ class BitbucketTest extends TestCase
         $this->io->expects($this->any())
             ->method('writeError')
             ->withConsecutive(
-                array('<error>Invalid OAuth consumer provided.</error>'),
-                array('This can have three reasons:'),
-                array('1. You are authenticating with a bitbucket username/password combination'),
-                array('2. You are using an OAuth consumer, but didn\'t configure a (dummy) callback url'),
-                array('3. You are using an OAuth consumer, but didn\'t configure it as private consumer')
+                ['<error>Invalid OAuth consumer provided.</error>'],
+                ['This can have three reasons:'],
+                ['1. You are authenticating with a bitbucket username/password combination'],
+                ['2. You are using an OAuth consumer, but didn\'t configure a (dummy) callback url'],
+                ['3. You are using an OAuth consumer, but didn\'t configure it as private consumer']
             );
 
         $this->httpDownloader->expects($this->once())
             ->method('get')
             ->with(
                 Bitbucket::OAUTH2_ACCESS_TOKEN_URL,
-                array(
+                [
                     'retry-auth-failure' => false,
-                    'http' => array(
+                    'http' => [
                         'method' => 'POST',
                         'content' => 'grant_type=client_credentials',
-                    ),
-                )
+                    ],
+                ]
             )
             ->willThrowException(
                 new \Composer\Downloader\TransportException(
@@ -247,21 +247,21 @@ class BitbucketTest extends TestCase
         $this->io->expects($this->any())
             ->method('writeError')
             ->withConsecutive(
-                array('<error>Invalid OAuth consumer provided.</error>'),
-                array('You can also add it manually later by using "composer config --global --auth bitbucket-oauth.bitbucket.org <consumer-key> <consumer-secret>"')
+                ['<error>Invalid OAuth consumer provided.</error>'],
+                ['You can also add it manually later by using "composer config --global --auth bitbucket-oauth.bitbucket.org <consumer-key> <consumer-secret>"']
             );
 
         $this->httpDownloader->expects($this->once())
             ->method('get')
             ->with(
                 Bitbucket::OAUTH2_ACCESS_TOKEN_URL,
-                array(
+                [
                     'retry-auth-failure' => false,
-                    'http' => array(
+                    'http' => [
                         'method' => 'POST',
                         'content' => 'grant_type=client_credentials',
-                    ),
-                )
+                    ],
+                ]
             )
             ->willThrowException(new \Composer\Downloader\TransportException('HTTP/1.1 401 UNAUTHORIZED', 401));
 
@@ -285,13 +285,13 @@ class BitbucketTest extends TestCase
             ->method('get')
             ->with(
                 Bitbucket::OAUTH2_ACCESS_TOKEN_URL,
-                array(
+                [
                     'retry-auth-failure' => false,
-                    'http' => array(
+                    'http' => [
                         'method' => 'POST',
                         'content' => 'grant_type=client_credentials',
-                    ),
-                )
+                    ],
+                ]
             )
             ->willThrowException($exception);
 
@@ -309,8 +309,8 @@ class BitbucketTest extends TestCase
         $this->io->expects($this->exactly(2))
             ->method('askAndHideAnswer')
             ->withConsecutive(
-                array('Consumer Key (hidden): '),
-                array('Consumer Secret (hidden): ')
+                ['Consumer Key (hidden): '],
+                ['Consumer Secret (hidden): ']
             )
             ->willReturnOnConsecutiveCalls($this->consumer_key, $this->consumer_secret);
 
@@ -323,9 +323,9 @@ class BitbucketTest extends TestCase
             )
             ->willReturn(
                 new Response(
-                    array('url' => $url),
+                    ['url' => $url],
                     200,
-                    array(),
+                    [],
                     sprintf(
                         '{"access_token": "%s", "scopes": "repository", "expires_in": 3600, "refresh_token": "refresh_token", "token_type": "bearer"}',
                         $this->token
@@ -364,8 +364,8 @@ class BitbucketTest extends TestCase
         $this->io->expects($this->exactly(2))
             ->method('askAndHideAnswer')
             ->withConsecutive(
-                array('Consumer Key (hidden): '),
-                array('Consumer Secret (hidden): ')
+                ['Consumer Key (hidden): '],
+                ['Consumer Secret (hidden): ']
             )
             ->willReturnOnConsecutiveCalls($this->consumer_key, null);
 
@@ -382,8 +382,8 @@ class BitbucketTest extends TestCase
         $this->io->expects($this->exactly(2))
             ->method('askAndHideAnswer')
             ->withConsecutive(
-                array('Consumer Key (hidden): '),
-                array('Consumer Secret (hidden): ')
+                ['Consumer Key (hidden): '],
+                ['Consumer Secret (hidden): ']
             )
             ->willReturnOnConsecutiveCalls($this->consumer_key, $this->consumer_secret);
 
@@ -407,11 +407,6 @@ class BitbucketTest extends TestCase
         $this->assertFalse($this->bitbucket->authorizeOAuthInteractively($this->origin, $this->message));
     }
 
-    /**
-     * @param bool $removeBasicAuth
-     *
-     * @return void
-     */
     private function setExpectationsForStoringAccessToken(bool $removeBasicAuth = false): void
     {
         $configSourceMock = $this->getMockBuilder('Composer\Config\ConfigSourceInterface')->getMock();
@@ -432,12 +427,12 @@ class BitbucketTest extends TestCase
             ->method('addConfigSetting')
             ->with(
                 'bitbucket-oauth.' . $this->origin,
-                array(
+                [
                     "consumer-key" => $this->consumer_key,
                     "consumer-secret" => $this->consumer_secret,
                     "access-token" => $this->token,
                     "access-token-expiration" => $this->time + 3600,
-                )
+                ]
             );
 
         if ($removeBasicAuth) {
@@ -454,8 +449,6 @@ class BitbucketTest extends TestCase
 
     /**
      * @depends testRequestAccessTokenWithValidOAuthConsumerAndValidStoredAccessToken
-     *
-     * @param Bitbucket $bitbucket
      */
     public function testGetTokenWithAccessToken(Bitbucket $bitbucket): void
     {
@@ -470,7 +463,7 @@ class BitbucketTest extends TestCase
     public function testAuthorizeOAuthWithoutAvailableGitConfigToken(): void
     {
         $process = $this->getProcessExecutorMock();
-        $process->expects(array(), false, array('return' => -1));
+        $process->expects([], false, ['return' => -1]);
 
         $bitbucket = new Bitbucket($this->io, $this->config, $process, $this->httpDownloader, $this->time);
 
